Module cli

Module cli 

Structs

Cli

Enums

CliCommand

Constants

CONFIG_ENV_VAR
DEFAULT_CONFIG_PATH

Functions

build_runtime
build_runtime_from_config
Build a runtime from a pre-loaded Config. Used by main so that the observability config can be read off the parsed Config to drive the logging subscriber before the runtime is built — without re-reading the file from disk.
list_components
resolve_config_path
validate_config